import Decimal from 'decimal.js';
type PriceFormatterProps = {
    price: number;
    fromSmallestUnit?: boolean;
    currency: {
        symbol: string;
        decimals: number;
    };
    pattern?: string;
    negative?: boolean;
};
/**
 * Formats a given price according to the specified currency and pattern and remove trailing zeros.
 *
 * @param {Object} params - The parameters for the price formatter.
 * @param {number} params.price - The price to be formatted.
 * @param {Object} params.currency - The currency properties.
 * @param {string} params.currency.symbol - The currency symbol.
 * @param {number} params.currency.decimals - The number of decimal places for the currency.
 * @param {boolean} [params.fromSmallestUnit=false] - Whether the price is in the smallest unit of the currency.
 * @param {boolean} [params.negative=false] - The pattern to format the price.
 * @returns {string} The formatted price string.
 */
export declare const priceFormatter: ({ price, currency: currencyProp, fromSmallestUnit, negative, }: PriceFormatterProps) => string;
export declare const ensureDecimal: (value: number | Decimal) => Decimal;
export declare const convertBack: (value: Decimal, decimals: number | Decimal) => number;
export declare const multiplyByDecimals: (value: Decimal, decimals: number | Decimal) => Decimal;
/**
 * Divide a value by decimals and convert back to the original unit, but if `returnSmallestUnit` is true, return the
 * smallest unit instead or main unit.
 * @param value
 * @param decimals
 * @param returnSmallestUnit
 */
export declare const divideConvertBackSmallestUnit: (value: Decimal, decimals: number | Decimal, returnSmallestUnit?: boolean) => number;
export {};
